#
# spec file for package wodim
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           wodim
Version:        1.1.11
Release:        25.3.1
Summary:        Tool for Writing CDRs
License:        GPL-2.0-only
Group:          Productivity/Multimedia/CD/Record

Url:            http://cdrkit.org/
Source0:        cdrkit-%{version}.tar.gz
Source1:        scan_scsi.linux
Source2:        cdinfo.c
Source5:        README.SUSE
Source6:        http://userpages.uni-koblenz.de/~krienke/ftp/noarch/geteltorito/geteltorito
# PATCH-FIX-OPENSUSE cdrkit-1.1.9-cmake.patch --
Patch0:         cdrkit-1.1.9-cmake.patch
# PATCH-FIX-OPENSUSE genisoimage-multi-extent.patch --
Patch1:         genisoimage-multi-extent.patch
# PATCH-FIX-OPENSUSE cdrkit-1.1.9-zlib-check.patch -- Fix cmake scripts to detect zlib-devel
Patch2:         cdrkit-1.1.9-zlib-check.patch
# PATCH-FIX-OPENSUSE cdrkit-1.1.9-fix-buffer-overflows.patch -- Fix buffer overflow warnings
Patch3:         cdrkit-1.1.9-fix-buffer-overflows.patch
# PATCH-FIX-UPSTREAM icedax.1_macro_warning_fix.patch asterios.dramis@gmail.com -- Fix rpmlint warning "manual-page-warning: macro `wav,' not defined" (already fixed upstream)
Patch4:         icedax.1_macro_warning_fix.patch
# PATCH-FIX-OPENSUSE genisoimage-multi-extent.patch-fix-bnc615177 --
Patch5:         genisoimage-multi-extent-fix-bnc615177.patch
# PATCH-FIX-OPENSUSE cdrkit-pie.diff lnussel@suse.de -- wodim must be pie as users may set suid bit on it
Patch6:         cdrkit-pie.diff
# PATCH-FIX-SLE fix-check_linux_26.patch bsc#897950 jkeil@suse.de
Patch7:         fix-check_linux_26.patch
Patch8:         genisoimage-fix-TRANS.TBL-with-large-files.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  gcc-c++
BuildRequires:  libbz2-devel
BuildRequires:  libcap-devel
BuildRequires:  perl
BuildRequires:  zlib-devel
Requires:       permissions
Requires(post): permissions
Requires(post): /bin/cp

%description
wodim is used to record data or audio CDs on a CD-Recorder or to write
DVD media on a DVD-Recorder.

%package -n cdrkit-devel-static
Summary:        Tool for Writing CDRs - Files Mandatory for Development
Group:          Development/Libraries/Other
Provides:       wodim-devel = %{version}
Obsoletes:      wodim-devel < %{version}

%description -n cdrkit-devel-static
This package contains cdrkit libraries mandatory for development.

%package -n genisoimage
Summary:        A Program for Creating CDs in Linux
Group:          Productivity/Multimedia/CD/Record
Recommends:     zisofs-tools

%description -n genisoimage
Genisoimage is a pre-mastering program that generates an iso9660
filesystem. It takes a snapshot of a given directory tree, and
generates a binary image which corresponds to an iso9660 filesystem
that can be written to a block device.

%package -n icedax
Summary:        A CD-Audio Grabbing tool
Group:          Productivity/Multimedia/CD/Grabbers
Requires:       vorbis-tools
# A handful of cdrtools programs, such as cdda2ogg(1),
# exist in icedax as well.
Conflicts:      cdda2wav

%description -n icedax
The common CD-audio grabbing tool for Linux. The sources are now
contained in the wodim source archive.

%package -n cdrkit-cdrtools-compat
Summary:        Tool for Writing CDRs - cdrtools Compatibility Package
Group:          Productivity/Multimedia/CD/Record
Requires:       genisoimage = %{version}-%{release}
Requires:       icedax = %{version}-%{release}
Requires:       wodim = %{version}-%{release}
Conflicts:      cdda2wav
Conflicts:      cdrecord
Conflicts:      mkisofs

%description -n cdrkit-cdrtools-compat
This package contains these symlinks:
cdrecord -> wodim
mkisofs -> genisoimage
cdda2wav -> icedax
Install this package if you want to use the cdrkit programs
using cdrtools program names.

%prep
%setup -q -n cdrkit-%{version}
%patch0
%patch1
%patch2
%patch3 -p1
%patch4
%patch5
%patch6 -p1
%patch7 -p1
%patch8 -p1
# Fix perl path
find . -type f -print0 | xargs -0 perl -pi -e 's#/usr/local/bin/perl#/usr/bin/perl#g'
# Fix permissions (no executables in doc files)
chmod 644 doc/icedax/tracknames.pl misc/burnstuff misc/rc.pp
# Rename in order to not conflict with doc/genisoimage/README when added in genisoimage rpm doc files
mv genisoimage/diag/README genisoimage/diag/README.diag

%build
export CFLAGS="%{optflags} -fno-strict-aliasing -DPIC -fPIC"
export CXXFLAGS="$CFLAGS"

mkdir build
cd build
cmake ../ -DCMAKE_INSTALL_PREFIX=%{_prefix}
# -DCMAKE_POSITION_INDEPENDENT_CODE=ON
make VERBOSE=1 MANDIR=share/man %{?_smp_mflags}
gcc %{optflags} %{S:2} -o cdinfo
cd ..

%install
b="%buildroot"
cd build
make install DESTDIR="%buildroot"
cd ..

# Fix perl version requirement
perl -pi -e 's#^require v5.8.1;##g' %{buildroot}%{_bindir}/dirsplit

# Install additional programs
install -pm 0755 build/cdinfo \
	         icedax/cdda2mp3.new \
                 icedax/inf2cdtext.pl \
                 %{S:1} \
                 %{buildroot}%{_bindir}
install -pm 0755 %{S:6} %{buildroot}%{_bindir}/geteltorito

# Compatibility symlinks
ln -sf wodim %{buildroot}%{_bindir}/cdrecord
ln -sf wodim %{buildroot}%{_bindir}/dvdrecord
ln -sf readom %{buildroot}%{_bindir}/readcd
ln -sf icedax %{buildroot}%{_bindir}/cdda2wav
ln -sf genisoimage %{buildroot}%{_bindir}/mkhybrid
ln -sf genisoimage %{buildroot}%{_bindir}/mkisofs
ln -sf wodim.1%{ext_man} %{buildroot}%{_mandir}/man1/cdrecord.1%{ext_man}
ln -sf readom.1%{ext_man} %{buildroot}%{_mandir}/man1/readcd.1%{ext_man}
ln -sf icedax.1%{ext_man} %{buildroot}%{_mandir}/man1/cdda2wav.1%{ext_man}
ln -sf genisoimage.1%{ext_man} %{buildroot}%{_mandir}/man1/mkisofs.1%{ext_man}

# Do not squat on cdrtools names in genisoimage package
# (do it in cdrkit-cdrtools-compat, which conflicts anyway)
mkdir -p "$b/%_libexecdir/genisoimage"
for i in devdump iso{debug,dump,info,vfy}; do
	mv "$b/%_bindir/$i" "$b/%_libexecdir/genisoimage/"
	ln -s "%_libexecdir/genisoimage/$i" "$b/%_bindir/"
	mv "$b/%_mandir/man1/$i.1" "$b/%_mandir/man1/genisoimage-$i.1"
	ln -s "genisoimage-$i.1%ext_man" "$b/%_mandir/man1/$i.1%ext_man"
done

# Other symlinks
ln -sf icedax %{buildroot}%{_bindir}/list_audio_tracks
ln -sf cdda2ogg.1%{ext_man} %{buildroot}%{_mandir}/man1/cdda2mp3.1%{ext_man}

# Install libraries
cd build
install -dm 0755 %{buildroot}%{_libdir}
install -pm 0644 \
                 librols/librols.a \
                 libusal/libusal.a \
                 %{buildroot}%{_libdir}
cd ..

# Install headers
rm -rf %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_includedir}/cdrkit
cp -a include/*.h %{buildroot}%{_includedir}/cdrkit
cp -a libusal/usal %{buildroot}%{_includedir}/
cp -a libusal/*.h %{buildroot}%{_includedir}/usal/
# it seems to depend on the cmake version if xconfig.h lands in ./ or in ./include/
# I don't know why, a cmake expert should fix that. Work around it for now.
cd build
if test -e xconfig.h; then # old cmake 2.6
	cp -a xconfig.h %{buildroot}%{_includedir}/cdrkit
elif ! test -e include/xconfig.h; then # new cmake 2.8
	echo "error: xconfig.h not found!"
	false
fi
cd ..

# Install config files
install -dm 0755 %{buildroot}%{_sysconfdir}
install -pm 0644 netscsid/netscsid.dfl %{buildroot}%{_sysconfdir}/netscsid.conf
install -pm 0644 wodim/wodim.dfl %{buildroot}%{_sysconfdir}/wodim.conf

# README.SUSE
cp %{S:5} .

# Missing man page. Do symlink like in Debian.
ln -sf wodim.1%{ext_man} %{buildroot}%{_mandir}/man1/netscsid.1%{ext_man}

%fdupes -s %buildroot/%_prefix

%verifyscript
%verify_permissions -e %{_bindir}/wodim

%post
%if 0%{?set_permissions:1} > 0
  %{set_permissions wodim}
%else
  %{run_permissions}
%endif

%files
%defattr(-,root,root,-)
%doc ABOUT COPYING Changelog FAQ FORK START TODO
%doc doc/ANNOUNCEMENTs/ doc/READMEs/ doc/wodim/
%doc misc/burnstuff misc/make_diskt@2.sh misc/rc.pp
%doc README.SUSE
%config(noreplace) %{_sysconfdir}/netscsid.conf
%config(noreplace) %{_sysconfdir}/wodim.conf
%{_bindir}/cdinfo
%{_bindir}/readom
%verify(not mode) %attr(0755,root,root) %{_bindir}/wodim
%attr(0555,root,root) %{_sbindir}/netscsid
%doc %{_mandir}/man1/netscsid.1%{ext_man}
%doc %{_mandir}/man1/readom.1%{ext_man}
%doc %{_mandir}/man1/wodim.1%{ext_man}

%files -n cdrkit-cdrtools-compat
%defattr(-,root,root,-)
%{_bindir}/cdda2wav
%{_bindir}/cdrecord
%{_bindir}/devdump
%{_bindir}/dvdrecord
%{_bindir}/mkhybrid
%{_bindir}/mkisofs
%{_bindir}/isodebug
%{_bindir}/isodump
%{_bindir}/isoinfo
%{_bindir}/isovfy
%{_bindir}/readcd
%doc %{_mandir}/man1/cdda2wav.1%{ext_man}
%doc %{_mandir}/man1/cdrecord.1%{ext_man}
%doc %{_mandir}/man1/devdump.1%{ext_man}
%doc %{_mandir}/man1/isodebug.1%{ext_man}
%doc %{_mandir}/man1/isodump.1%{ext_man}
%doc %{_mandir}/man1/isoinfo.1%{ext_man}
%doc %{_mandir}/man1/isovfy.1%{ext_man}
%doc %{_mandir}/man1/mkisofs.1%{ext_man}
%doc %{_mandir}/man1/readcd.1%{ext_man}

%files -n cdrkit-devel-static
%defattr(-,root,root,-)
%{_includedir}/cdrkit/
%{_includedir}/usal/
%{_libdir}/lib*.a

%files -n genisoimage
%defattr(-,root,root,-)
%doc doc/genisoimage/*
%{_bindir}/dirsplit
%{_bindir}/genisoimage
%{_bindir}/geteltorito
%_libexecdir/genisoimage/
%doc %{_mandir}/man1/genisoimage-devdump.1%{ext_man}
%doc %{_mandir}/man1/dirsplit.1%{ext_man}
%doc %{_mandir}/man1/genisoimage.1%{ext_man}
%doc %{_mandir}/man1/genisoimage-isodebug.1%{ext_man}
%doc %{_mandir}/man1/genisoimage-isodump.1%{ext_man}
%doc %{_mandir}/man1/genisoimage-isoinfo.1%{ext_man}
%doc %{_mandir}/man1/genisoimage-isovfy.1%{ext_man}
%doc %{_mandir}/man5/genisoimagerc.5%{ext_man}

%files -n icedax
%defattr(-,root,root,-)
%doc doc/icedax/*
%{_bindir}/cdda2mp3
%{_bindir}/cdda2mp3.new
%{_bindir}/cdda2ogg
%{_bindir}/icedax
%{_bindir}/inf2cdtext.pl
%{_bindir}/list_audio_tracks
%{_bindir}/pitchplay
%{_bindir}/readmult
%{_bindir}/scan_scsi.linux
%doc %{_mandir}/man1/cdda2mp3.1%{ext_man}
%doc %{_mandir}/man1/cdda2ogg.1%{ext_man}
%doc %{_mandir}/man1/icedax.1%{ext_man}
%doc %{_mandir}/man1/list_audio_tracks.1%{ext_man}
%doc %{_mandir}/man1/pitchplay.1%{ext_man}
%doc %{_mandir}/man1/readmult.1%{ext_man}

%changelog
* Fri Jul 27 2018 jdelvare@suse.com
- add genisoimage-fix-TRANS.TBL-with-large-files.patch: fix a crash
  when option -T (generate TRANS.TBL) is used in conjunction with
  multi-extent files (files larger than 4 GB) (bsc#1100466)
* Tue Sep  1 2015 jkeil@suse.de
- add fix-check_linux_26.patch: also compare major kernel version
  number. (bsc#897950)
* Thu Aug 13 2015 dmueller@suse.com
- remove cdrkit-1.1.8-werror.patch, cdrkit-efi-boot.patch (bsc#939456)
* Wed Jul  8 2015 dmueller@suse.com
- disable source download service, upstream download location
  is dead
* Tue Jun  9 2015 jkeil@suse.de
- Use full url as source
* Tue Jun  9 2015 jkeil@suse.de
- Update geteltorito script to latest version
  source: http://userpages.uni-koblenz.de/~krienke/ftp/noarch/geteltorito/geteltorito
* Fri Jan 30 2015 dmueller@suse.com
- add cdrkit-1.1.8-werror.patch, cdrkit-efi-boot.patch (fate#318444)
* Fri Jun 20 2014 lnussel@suse.de
- make wodim position independent (bnc#882035, cdrkit-pie.diff)
* Wed Mar  5 2014 nadvornik@suse.com
- fixed large file support (bnc#615177, bnc#831820)
  genisoimage-multi-extent-fix-bnc615177.patch
* Thu Jun  6 2013 jengelh@inai.de
- Avoid calling fdupes on entire buildroot; it is not valid for /etc
- Install manpage symlinks inside cdrkit-cdrtools-compat
- Remove static libraries for which there are no header files
  packaged
* Wed Jun  5 2013 jengelh@inai.de
- Avoid collision of iso{dump,vfy} etc. by moving binaries into
  separate directory. This allows parallel installation of mkisofs
  and genisoimage.
* Thu Apr 18 2013 coolo@suse.com
- switch _service to localonly
* Tue Apr  2 2013 jengelh@inai.de
- Dissolve Obsoletes cycle between cdrkit (source package "wodim")
  and cdrtools. Add proper Conflicts instead.
- Use more robust make install call; kill redundant %%clean section
* Thu Apr  7 2011 davejplater@gmail.com
- Fixed provides/requires to enable clean installation of cdrtools
  and vice versa.
* Mon Apr  4 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added "libbz2-devel" in BuildRequires:.
  * Added "permissions" package in Requires:.
  * Moved mkhybrid to cdrkit-cdrtools-compat.
  * Install also libedc.a library.
  * Changed the installation path of header files (to be more compatible with
    Fedora, at least for libusal).
  * Changed wodim-devel package name to cdrkit-devel-static.
  * Added "-DPIC -fPIC" in CFLAGS to built the static libraries.
  * Added smp_mflags to make.
  * Install config files in /etc.
  * Updates in %%post installation script of wodim according to openSUSE spec
    file guidelines.
  * Updates in %%files sections.
  * Minor other updates.
- Added a patch from upstream for icedax.1 to fix rpmlint warning "macro `wav,'
  not defined".
* Sat Feb 19 2011 asterios.dramis@gmail.com
- updated to 1.1.11:
  * genisoimage: Fix silly bug in MD5 output in template files. (Debian
    bug #596681)
  * genisoimage: Minor tweaks to the the genisoimage.1 man page.
  * genisoimage: Update references to atterer.org (Debian bug #596860)
  * genisoimage.1: Make the description of the md5-list format clearer.
  * genisoimage: Use memmove() instead of strcpy() when cleaning
    up graft points.
- Spec file updates:
  - Changes based on rpmdevtools templates and spec-cleaner run.
  - Changed License: to GPLv2.
  - Added description for patches based on openSUSE Patches Guidelines (where
    possible).
  - Updates in Buildrequires:, Requires:,
  - Updates in %%prep, %%build and %%install sections.
  - Fixed rpmlint warnings ("description-shorter-than-summary" for wodim-devel
    and "files-duplicate").
  - Other updates based also on Fedora package.
* Tue Sep 28 2010 reddwarf@opensuse.org
- updated to 1.1.10:
  * genisoimage: add support for sha256 and sha512 checksum generation
    when making jigdo files.
  * genisoimage: checksumming with lots of algorithms can be very
    time-consuming, so split it out into multiple threads if possible.
  * genisoimage: allow user to specify which checksum algorithms to run
    on the command line.
  * Fix FTBFS with missing xconfig.h. Thanks to Matt Kraai for the patch.
  * genisoimage: fix string overflow breakage when using the -root
    option (https://bugzilla.redhat.com/show_bug.cgi?id=508449)
  * librols: remove or rename several functions that clash with POSIX.
    Fix up callers.
* Mon Feb 22 2010 seife@opensuse.org
- fix buffer overflow warnings from gcc-4.5
* Mon Feb 15 2010 seife@opensuse.org
- fix xconfig.h installation with newer cmake
* Fri Oct  2 2009 crrodriguez@opensuse.org
- build require zlib-devel and fix cmake scripts to detect
  when it is missing.
* Fri Jun  5 2009 nadvornik@suse.cz
- updated to 1.1.9:
  * wodim: In -msinfo mode, only suggest dvd+rw-mediainfo in verbose mode.
  * genisoimage: undo a mistake in the directory permissions change in
    the last release. Fixes handling of deep directory structures.
- fixed build with glibc 2.10
* Wed Sep 10 2008 nadvornik@suse.cz
- fixed genisoimage crash with -hfs [bnc#425045]
* Mon Sep  8 2008 nadvornik@suse.cz
- updated to bugfix release 1.1.8
- ported support for files >4GB on iso9660 (see the option
  - iso-level 3) [fate#303791]
* Fri Aug 22 2008 lnussel@suse.de
- remove resmgr from BuildRequires
* Tue Apr  8 2008 nadvornik@suse.cz
- update to 1.1.7.1:
  * genisoimage: support for bzip2-compressed templates
  * genisoimage: generic infrastructure for checksums
  * bugifixes
* Sat Feb 16 2008 schwab@suse.de
- Fix whitespace in messages.
* Thu Dec 13 2007 nadvornik@suse.cz
- more fixes in xconfig.h, required for building cdrdao
* Wed Nov 21 2007 nadvornik@suse.cz
- fixed a bug in genisoimage [#342534]
* Wed Oct 24 2007 nadvornik@suse.cz
- use autoconf-compatible values in xconfig.h
* Thu Jun 28 2007 nadvornik@suse.cz
- updated to 1.1.6:
  * adding generic drive guessing
  * some bugfixes
* Thu May  3 2007 nadvornik@suse.cz
- fixed crash on hidden boot catalog directory [#247950]
* Tue Apr 24 2007 nadvornik@suse.cz
- update to cdrkit-1.1.5.1
  - experimental Large File Support with UDF filesystem
  - prefer /dev/scg if device is specified with b/t/l
* Thu Feb  8 2007 nadvornik@suse.cz
- do not use icedax/md5c.c and icedax/md5.h [#240669]
* Mon Jan 22 2007 nadvornik@suse.cz
- updated to cdrkit-1.1.2
  * many patches merged upstream
  * more programs was renamed:
    mkisofs -> genisoimage
    readcd -> readom
    cdda2wav -> icedax
  * 'wodim -devices' scans for all usable devices
- subpackages renamed respectively
- compatibility symlinks put to new cdrkit-cdrtools-compat package
* Mon Nov 27 2006 nadvornik@suse.cz
- copy cdrecord config file on update [#221679]
* Thu Nov 16 2006 nadvornik@suse.cz
- adjusted version strings of subpackages [#215621]
- changed location of config file [#221679]
* Fri Oct  6 2006 nadvornik@suse.cz
- moved include files to /usr/include/wodim
* Tue Oct  3 2006 nadvornik@suse.cz
- removed incorrect check for grown files [#207619]
- build with -DCLONE_WRITE [#209434]
* Thu Sep 21 2006 nadvornik@suse.cz
- switched to cdrkit package, cdrecord is replaced by wodim
- UTF8, dvd and other patches are integrated in upstream
* Fri Sep  1 2006 nadvornik@suse.cz
- use Recommends: zisofs-tools instead of Requires:
* Mon Aug  7 2006 ro@suse.de
- define HZ to sysconf(_SC_CLK_TCK) if not defined
* Thu Mar 23 2006 nadvornik@suse.cz
- updated feedback URL [#160326]
* Tue Feb 14 2006 nadvornik@suse.cz
- do not try to redefine printf before including stdio.h
* Thu Feb  2 2006 nadvornik@suse.cz
- removed confusing messages about the recommended interface
  and added README.SUSE [#147236]
- do not stop scanning on inaccessible devices [#144843, #147236]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 lnussel@suse.de
- restore original behavior of also enumerating sg devices when not
  running root (#141228)
* Mon Jan  2 2006 nadvornik@suse.cz
- fixed dangerous compiler warnings
- added workaround for gcc.gnu.org/PR25639
* Tue Oct 11 2005 nadvornik@suse.cz
- built with -fno-strict-aliasing again as new problems appeared
* Fri Aug 12 2005 nadvornik@suse.cz
- patched mkisofs to fail on file > 4GB [#80583]
* Fri Apr  1 2005 uli@suse.de
- fixed to build on ARM(v5tel)
* Tue Feb  8 2005 nadvornik@suse.cz
- call mlockall only for getuid() == 0
* Mon Sep 13 2004 nadvornik@suse.cz
- updated to final 2.01 [#43565]
- -fno-strict-aliasing is no longer required
* Tue Sep  7 2004 nadvornik@suse.cz
- fixed possible problems in resmgr and iconv patches
- use generic_scsi interface as default for all devices in cdda2wav
* Mon Aug 23 2004 nadvornik@suse.cz
- updated to 2.01a35 [#43565]
- DVD patch is applied to separate binary cdrecord-dvd
- dropped silo patch
- dropped the privacy patch, added note to mkisofs manpage instead [#33275]
- compiled with -fno-strict-aliasing to minimize needed patches
- fixed printing error messages from resmgr patch [#44024]
* Mon Apr 19 2004 nadvornik@suse.cz
- fixed function return value
* Fri Apr  2 2004 nadvornik@suse.cz
- changed some strings from 8859-1 to UTF-8 [37840]
  a better fix would be either use only ascii characters or use locale
* Fri Mar 26 2004 nadvornik@suse.cz
- do not scan ATA devices if no scsi devices are found, because
  the output would be confusing [#37081]
- fixed return value from fixate_mdvd
* Mon Mar  8 2004 nadvornik@suse.cz
- updated to 2.01a27
  - chrp-boot patch is integrated in mainstream
  - TAO mode should be explicitely specified by -tao
* Thu Feb 12 2004 axboe@suse.de
- Kill silly Joerg warnings
- Add note about ATA being preferred over ATAPI
* Wed Feb  4 2004 nadvornik@suse.cz
- added iconv patch to mkisofs [#34274]
- fixed scanning of ATA devices with resmgr
- fixed dangerous gcc warnings
* Thu Jan 29 2004 nadvornik@suse.cz
- updated to 2.01a25
- updated dvd patch - DVD+RW support
- added geteltorito script to mkisofs package
- fixed information leak in mkisofs by using debian patch [#33275]
- fixed paride handling in resmgr patch [#29601]
- try to open device directly if resmgr fails
- built as non-root user
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Oct 30 2003 ro@suse.de
- package according to permissions.secure and call run_permissions
* Thu Sep 11 2003 nadvornik@suse.cz
- added new resmgr patch with paride support from okir@suse.de [#29601]
* Wed Sep 10 2003 nadvornik@suse.cz
- made the check for sequential recording silent
* Fri Sep  5 2003 nadvornik@suse.cz
- fixed return value from getdisktype_mdvd
* Sat Aug 30 2003 ro@suse.de
- create cdrecord-devel package and package libscg files
* Wed Aug 13 2003 nadvornik@suse.cz
- updated to 2.01a18
- added patch for dvd support
* Mon Aug 11 2003 nadvornik@suse.cz
- added chrp-boot patch
* Wed May 28 2003 nadvornik@suse.cz
- remove/install unpackaged files from buildroot
* Mon Jan 13 2003 nadvornik@suse.cz
- updated to 2.0 final
* Wed Dec 18 2002 froh@suse.de
- re-enable cdda2wav on s390 (#22498)
* Tue Nov  5 2002 okir@suse.de
- Proactive security patch: added resmgr support - cdrecord now
  performs a minimum of initialization as root, then drops privileges
  and uses resmgr to access device files.
* Thu Sep 26 2002 nadvornik@suse.cz
- removed zisofs-tools, it is a separate package,
- mkisofs requires zisofs-tools
* Tue Sep 24 2002 nadvornik@suse.cz
- updated to 1.11a34
  - a bug with cdrecord -fix has been fixed [#19853]
  - improved man page
  - other fixes and improvements
- added zisofs-tools for transparent compression
* Tue Sep  3 2002 nadvornik@suse.cz
- added patch for format string security problem [#18756]
* Wed Jul 31 2002 nadvornik@suse.cz
- updated to 1.11a28
  - cdrecord now writes MCN/ISRC even in RAW mode
* Fri Jul 26 2002 nadvornik@suse.cz
- updated to 1.11a27:
  - DVD-Video support
* Wed Jul 10 2002 meissner@suse.de
- add RULES link for ppc64, s390x.
* Tue May 14 2002 ro@suse.de
- add RULES link for x86_64
* Tue Apr 30 2002 uli@suse.de
- update -> 1.11a21 (fixes probs with xcdroast >=0.98alpha9)
* Fri Mar  1 2002 nadvornik@suse.cz
- fixed man pages for isodump, devdump, isovfy [bug #14012]
* Tue Feb 26 2002 nadvornik@suse.cz
- fixed "#!/bin/sh" line in cdda2mp3.new
* Mon Jan 21 2002 nadvornik@suse.cz
- updated to 1.11a13:
  - new script inf2cdtext.pl for creating CD-text data
* Fri Dec  7 2001 nadvornik@suse.cz
- updated to 1.11a12:
  - readcd: changed handling of Table of contents
  - mkisofs: first UDF support
* Tue Oct 30 2001 uli@suse.de
- added patch from zisofs-tools allowing for creation of compressed
  ISO filesystems
* Mon Sep  3 2001 nadvornik@suse.cz
- changed version string 1.11a06 -> 1.11.a06
* Tue Aug 14 2001 nadvornik@suse.cz
- update to 1.11a06
* Thu Jul 12 2001 nadvornik@suse.cz
- update to 1.11a05
- can be built with all kernels
* Mon Jun 18 2001 schwab@suse.de
- Fix to compile.
* Thu Apr 26 2001 ro@suse.de
- added config-dist.sh
* Fri Feb  9 2001 ro@suse.de
- fixed to compile
* Fri Jan 19 2001 kukuk@suse.de
- fix missing exit
* Fri Jan 19 2001 kukuk@suse.de
- cdrecord should only be build on kernel 2.2
* Mon Dec 11 2000 ro@suse.de
- fixed group typos
* Tue Oct 17 2000 bk@suse.de
- Use ppc-linux rules for s390.
* Mon Oct  9 2000 smid@suse.cz
- New version 1.9
* Tue Sep 19 2000 schwab@suse.de
- Use i586-linux rules for ia64.
- Add %%suse_update_config.
* Fri Jul 21 2000 smid@suse.cz
- Merge patches for booting SPARCs/silo with version 1.8.1
* Wed Jun  7 2000 cihlar@suse.cz
- Copyright tag fixed
* Wed May 31 2000 cihlar@suse.cz
- update to version 1.8.1
* Fri Apr  7 2000 smid@suse.cz
- buildroot added
* Fri Mar 24 2000 kukuk@suse.de
- Merge patches for booting SPARCs/silo
* Sun Feb 20 2000 bk@suse.de
- added link /usr/bin/list_audio_tracks -> cdda2wav (needed for cdda2mp3)
* Sun Feb  6 2000 olh@suse.de
- update cdrecord to 1.8
  update mkhybrid to 1.12b5.4
  make apple_driver for bootable Mac CD's
* Thu Jan 13 2000 ro@suse.de
- update to a40-3
* Mon Dec 20 1999 ro@suse.de
- update to a35
* Mon Oct 18 1999 ro@suse.de
- update to a30
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 24 1999 uli@suse.de
- now building mkhybrid with -fsigned-char (PPC)
* Mon Aug  9 1999 ro@suse.de
- update to 1.8a24
* Mon Jul 12 1999 ro@suse.de
- update to a23
* Tue Jun  1 1999 ro@suse.de
- update to 1.8a22 (mkisofs-1.12b5)
* Thu Apr  8 1999 ro@suse.de
- update to 1.8a20
* Mon Mar  8 1999 ro@suse.de
- update to 1.8a19
* Mon Feb 15 1999 ro@suse.de
- update to 1.8a17
- mkisofs and cdda2wav are built from same sources
* Tue Dec  1 1998 ro@suse.de
- update to 1.8a13
* Mon Nov  2 1998 ro@suse.de
- update to 1.6.1
* Mon Apr 20 1998 ro@suse.de
- update to 1.6 final
* Tue Mar  3 1998 ro@suse.de
- update to 1.6a9  includes new fifo code
* Wed Nov 12 1997 ms@suse.de
- initial package for suse version 1.5
